You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by as...@apache.org on 2015/08/22 01:08:54 UTC

svn commit: r1697068 - /qpid/trunk/qpid/cpp/BuildInstallSettings.cmake

Author: astitcher
Date: Fri Aug 21 23:08:54 2015
New Revision: 1697068

URL: http://svn.apache.org/r1697068
Log:
NO-JIRA: Fix RPATH setting for rpm builds which set absolute paths
- specifically matters for the LIB_INSTALL_DIR which is also used
  to set the RPATH in some circumstances.

Modified:
    qpid/trunk/qpid/cpp/BuildInstallSettings.cmake

Modified: qpid/trunk/qpid/cpp/BuildInstallSettings.cmake
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/cpp/BuildInstallSettings.cmake?rev=1697068&r1=1697067&r2=1697068&view=diff
==============================================================================
--- qpid/trunk/qpid/cpp/BuildInstallSettings.cmake (original)
+++ qpid/trunk/qpid/cpp/BuildInstallSettings.cmake Fri Aug 21 23:08:54 2015
@@ -128,7 +128,7 @@ if (UNIX)
     endif()
   endif()
 
   # In rpm builds the build sets some variables:
   #  CMAKE_INSTALL_PREFIX - this is a standard cmake variable
   #  INCLUDE_INSTALL_DIR
   #  LIB_INSTALL_DIR
@@ -181,8 +181,9 @@ if (UNIX)
   set(CMAKE_INSTALL_RPATH_USE_LINK_PATH TRUE)
 
   # The RPATH to be used when installing, but only if it's not a system directory
-  list(FIND CMAKE_PLATFORM_IMPLICIT_LINK_DIRECTORIES "${CMAKE_INSTALL_PREFIX}/${LIB_INSTALL_DIR}" isSystemDir)
+  set_absolute_install_path (QPID_LIB_DIR ${QPID_INSTALL_LIBDIR})
+  list(FIND CMAKE_PLATFORM_IMPLICIT_LINK_DIRECTORIES "${QPID_LIB_DIR}" isSystemDir)
   if("${isSystemDir}" STREQUAL "-1")
-    set(CMAKE_INSTALL_RPATH "${CMAKE_INSTALL_PREFIX}/${LIB_INSTALL_DIR}")
+    set(CMAKE_INSTALL_RPATH "${QPID_LIB_DIR}")
   endif("${isSystemDir}" STREQUAL "-1")
 endif (UNIX)



---------------------------------------------------------------------
@@ -128,7 +128,7 @@ if (UNIX)
   endif()
 
-  # In rpm builds the build sets some variables:
+  # In rpm builds the build sets some variables with absolute paths:
   #  CMAKE_INSTALL_PREFIX - this is a standard cmake variable
   #  INCLUDE_INSTALL_DIR
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org